@@ -3,14 +3,15 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
-/* FIXME:
- Check these declarations against the C/Fortran source code.
- */
+/* FIXME: 
+   Check these declarations against the C/Fortran source code.
+*/
 
 /* .C calls */
 extern void PROJ_proj_trans_generic(void *, void *, void *, void *, void *, void *, void *, void *);
 
 /* .Call calls */
+extern SEXP PROJ_proj_create(SEXP, SEXP);
 extern SEXP PROJ_set_data_dir(SEXP);
 
 static const R_CMethodDef CEntries[] = {
@@ -19,6 +20,7 @@ static const R_CMethodDef CEntries[] = {
 };
 
 static const R_CallMethodDef CallEntries[] = {
+    {"PROJ_proj_create",  (DL_FUNC) &PROJ_proj_create,  2},
     {"PROJ_set_data_dir", (DL_FUNC) &PROJ_set_data_dir, 1},
     {NULL, NULL, 0}
 };
