@@ -8,9 +8,10 @@ dst <- "+proj=laea +datum=WGS84 +lon_0=147 +lat_0=-42"
 test_that("PROJ works", {
   if (!ok_proj6()) skip("no PROJ6 available, no real testing to do")
 
-  expect_silent(xyz <- proj_trans_generic(cbind(X = lon, Y = lat), z_ = rep(0, length(lon)), dst, source = "WGS84"))
+  src <- "+proj=longlat +datum=WGS84"
+  expect_silent(xyz <- proj_trans_generic(cbind(X = lon, Y = lat), z_ = rep(0, length(lon)), dst, source = src))
   expect_silent(lonlat <- proj_trans_generic(cbind(X = xyz["x_"], Y = xyz["y_"]), z_ = rep(0, length(lon)),
-                                     "WGS84", source = dst))
+                                     src, source = dst))
   expect_true(all(lonlat[["x_"]] <= 180))
   expect_true(all(lonlat[["x_"]] > -180))
   expect_true(all(lonlat[["y_"]] < 90))
